Daemon rucio-conveyor-poller — Rucio 1.2 documentation

# Daemon rucio-conveyor-poller

    usage: rucio-conveyor-poller [-h] [--run-once] [--fts-bulk FTS_BULK]
                                 [--db-bulk DB_BULK] [--older-than OLDER_THAN]
                                 [--sleep-time SLEEP_TIME]
                                 [--activities ACTIVITIES [ACTIVITIES ...]]
                                 [--activity-shares ACTIVITY_SHARES]
                                 [--total-threads TOTAL_THREADS]

## Named Arguments

`--run-once` | One iteration only Default: False
`--fts-bulk` | Bulk control: number of transfers per FTS query Default: 100
`--db-bulk` | Bulk control: number of transfers per db query Default: 1000
`--older-than` | Poll control: older request more than this value to poll Default: 60
`--sleep-time` | Seconds to sleep if few requests Default: 300
`--activities` | Explicit list of activities to include
`--activity-shares`
| JSON-encoded string of an activity shares dictionary {“act_1”: 0.2, “act_2”: 0.4, …}
`--total-threads`
| Concurrency control: total number of threads for this process Default: 1